@@ -18,8 +18,10 @@ class HunterService(Service):
         self.boot_time = boot_time
         self.clean()
 
-    def start(self):
-        filename = self.results_dir + "/hunter-%s.log" % (str(self.boot_time))
+    def start(self, file_id=None):
+        if file_id is None:
+            file_id = execute_shell_command("date +%s")[1].strip()
+        filename = self.results_dir + "/hunter-%s-%s.log" % (file_id, str(self.boot_time))
         log("Hunter file:  %s" % filename)
         execute_shell_command("adb logcat -d | grep -io \"[<>].*m=example.*]\" > %s" % filename)
         return filename
@@ -28,6 +30,7 @@ class HunterService(Service):
         pass
 
     def clean(self):
+        execute_shell_command("find %s -type f  | xargs rm " % self.results_dir)
         execute_shell_command("adb logcat -c")  # or   adb logcat -b all -c
 
     # parses function to other module HunterParser
@@ -37,25 +40,39 @@ class HunterService(Service):
             self.parseHistory(lines)
 
     def parseHistory(self, lines_list):
+        not_functions = ["<init>", "get", "set"]
+
         for i, line in enumerate(lines_list):
             if re.match(r"^>", line):
                 before_components = re.split('^>', line)
                 components = re.split('[,=\[\] ]', before_components[1])
                 function_name = components[0]
-                begin_time = components[13]
-                if function_name not in self.trace:
-                    self.trace[function_name] = {}
-                    self.trace[function_name][0] = {'begin_time': float(begin_time) * (pow(10, -3))}
-                elif len(self.trace[function_name]) not in self.trace[function_name]:
-                    self.trace[function_name][len(self.trace[function_name])] = {
-                        'begin_time': float(begin_time) * (pow(10, -3))}
+                add_function = True
+                for not_function in not_functions:
+                    if not_function in function_name:
+                        add_function = False
+                        break
+                if add_function:
+                    begin_time = components[13]
+                    if function_name not in self.trace:
+                        self.trace[function_name] = {}
+                        self.trace[function_name][0] = {'begin_time': float(begin_time) * (pow(10, -3))}
+                    elif len(self.trace[function_name]) not in self.trace[function_name]:
+                        self.trace[function_name][len(self.trace[function_name])] = {
+                            'begin_time': float(begin_time) * (pow(10, -3))}
             elif re.match(r"^<", line):
                 before_components = re.split('^<', line)
                 components = re.split('[,=\[\] ]', before_components[1])
                 function_name = components[0]
-                end_time = components[13]
-                self.trace[function_name][len(self.trace[function_name]) - 1].update(
-                    {'end_time': float(end_time) * (pow(10, -3))})
+                add_function = True
+                for not_function in not_functions:
+                    if not_function in function_name:
+                        add_function = False
+                        break
+                if add_function:
+                    end_time = components[13]
+                    self.trace[function_name][len(self.trace[function_name]) - 1].update(
+                        {'end_time': float(end_time) * (pow(10, -3))})
             else:
                 print("linha invalida" + line)
 
@@ -69,6 +86,7 @@ class HunterService(Service):
         )
 
     def addConsumptionToTraceFile(self, filename):
+        not_functions = ["<init>", "get", "set"]
         with open(filename, 'r+') as fr, open(filename, 'r+') as fw:
             for line in fr:
                 checked = False
@@ -81,12 +99,18 @@ class HunterService(Service):
                     components = re.split('[,=\[\] ]', before_components[1])
                     function_name = components[0]
                     checked = True
-                consumption, time = self.returnConsumptionAndTimeByFunction(function_name, checked)
-                cpu = re.split('cpu = \d+', line)
-                if (len(cpu) < 2):
-                    fw.write(line)
-                else:
-                    fw.write(cpu[0] + 'cpu = ' + str(consumption) + ', t = ' + str(time) + ']\n')
+                add_function = True
+                for not_function in not_functions:
+                    if not_function in function_name:
+                        add_function = False
+                        break
+                if add_function:
+                    consumption, time = self.returnConsumptionAndTimeByFunction(function_name, checked)
+                    cpu = re.split('cpu = \d+', line)
+                    if len(cpu) < 2:
+                        fw.write(line)
+                    else:
+                        fw.write(cpu[0] + 'cpu = ' + str(consumption) + ', t = ' + str(time) + ']\n')
             fw.truncate()
 
     def returnConsumptionAndTimeByFunction(self, function_name, checked):
@@ -94,8 +118,8 @@ class HunterService(Service):
         time = 0.0
         for i, times in enumerate(self.trace[function_name]):
             results = self.trace[function_name][i]
-            if (results['checked'] == False):
-                if (checked):
+            if not results['checked']:
+                if checked:
                     consumption = results['consumption']
                     time = results['end_time']
                     self.updateChecked(function_name, i)
