@@ -11,10 +11,10 @@ from manafa.utils.Utils import execute_shell_command, get_resources_dir
 
 RESOURCES_DIR = get_resources_dir()
 
-DEFAULT_OUT_DIR = "/sdcard/perfetto-traces"
+DEFAULT_OUT_DIR = "/data/misc/perfetto-traces"
 
 class PerfettoService(Service):
-	"""docstring for BatteryStatsService"""
+	"""docstring for BatteryStatService"""
 	def __init__(self, boot_time=0, output_res_folder="perfetto", default_out_dir=DEFAULT_OUT_DIR):
 		Service.__init__(self, output_res_folder)
 		self.boot_time = boot_time
@@ -44,7 +44,7 @@ class PerfettoService(Service):
 
 	def export(self):
 		last_exported = ""
-		for f in filter( lambda x : re.match(r'trace-*', x) is not None,  os.listdir(self.results_dir)):
+		for f in filter(lambda x : re.match(r'trace-*', x) is not None,  os.listdir(self.results_dir)):
 			res, o, e = execute_shell_command("chmod +x %s/traceconv ; %s/traceconv systrace %s/%s %s/%s.systrace" %(RESOURCES_DIR,RESOURCES_DIR,self.results_dir,f,self.results_dir,f) )
 			last_exported = "%s/%s.systrace" %(self.results_dir,f)
 		return last_exported
