@@ -1,26 +1,29 @@
+import os
 import sysconfig
 from subprocess import Popen, PIPE
 from textops import find
 
 DEV=False
 
-def get_resources_dir(packname="manafa", default_res_dir="resources"):
+def get_reference_dir(packname):
     if DEV:
-        return packname + "/" + default_res_dir
-    return sysconfig.get_path("purelib") + "/git " + packname + "/" + default_res_dir
+        return packname
+    else:
+        base_dir = sysconfig.get_path("purelib")
+        return os.path.join(base_dir, packname)
+
+def get_resources_dir(packname="manafa", default_res_dir="resources"):
+    ref_dir = get_reference_dir(packname)
+    return os.path.join(ref_dir, default_res_dir)
 
 
 def get_pack_dir(packname="manafa"):
-    if DEV:
-        return packname
-    return sysconfig.get_path("purelib") + "/" + packname
+    return get_reference_dir(packname)
 
 
 def get_results_dir(packname="manafa", default_results_dir="results"):
-    if DEV:
-        return packname + "/" + default_results_dir
-    return sysconfig.get_path("purelib") + "/" + packname + "/" + default_results_dir
-    #return packname + "/" + default_results_dir
+    ref_dir = get_reference_dir(packname)
+    return os.path.join(ref_dir, default_results_dir)
 
 
 def execute_shell_command(cmd, args=[]):
